import 'package:freezed_annotation/freezed_annotation.dart';
import 'package:sghi_core/afya_moja_core/afya_moja_core.dart';
import 'package:sghi_core/communities/core/enums.dart';

part 'message.freezed.dart';
part 'message.g.dart';

/// Represents a Matrix event message.
@freezed
class Message with _$Message {
  /// Creates a new [Message] instance.
  factory Message({
    /// The event type of the message.
    @JsonKey(name: 'type') String? eventType,

    /// The sender of the message.
    @JsonKey(name: 'sender') String? sender,

    /// The content of the message.
    @JsonKey(name: 'content') MessageContent? content,

    /// The timestamp of the message.
    @JsonKey(name: 'origin_server_ts') int? timeStamp,

    /// The ID of the event.
    @JsonKey(name: 'event_id') String? eventID,

    /// The ID of the room where the message is sent.
    @JsonKey(name: 'room_id') String? roomID,

    // The Matrix user ID of the user whose membership state is being updated
    @JsonKey(name: 'state_key') String? stateKey,
  }) = _Message;

  /// Creates a [Message] instance from a JSON map.
  factory Message.fromJson(Map<String, dynamic> json) =>
      _$MessageFromJson(json);

  /// Creates an initial [Message] instance.
  factory Message.initial() => Message(
        eventType: UNKNOWN,
        sender: UNKNOWN,
        content: MessageContent.initial(),
        timeStamp: 0,
        eventID: UNKNOWN,
        stateKey: UNKNOWN,
        roomID: UNKNOWN,
      );
}

/// Represents the content of a Matrix event message.
@freezed
class MessageContent with _$MessageContent {
  /// Creates a new [MessageContent] instance.
  factory MessageContent({
    /// The type of the message.
    @JsonKey(name: 'msgtype') String? msgType,

    /// The body of the message.
    @JsonKey(name: 'body') String? body,

    /// The topic of the room.
    @JsonKey(name: 'topic') String? topic,

    /// The name of the room.
    @JsonKey(name: 'name') String? name,

    /// The guest access of the room.
    @JsonKey(name: 'guest_access') String? guestAccess,

    /// The history visibility of the room.
    @JsonKey(name: 'history_visibility') String? historyVisibility,

    /// The join rule of the room.
    @JsonKey(name: 'join_rule') String? joinRule,

    /// The alias of the room.
    @JsonKey(name: 'alias') String? alias,

    /// The creator of the room.
    @JsonKey(name: 'creator') String? creator,

    /// The version of the room.
    @JsonKey(name: 'room_version') String? roomVersion,

    /// The users of the room.
    @JsonKey(name: 'users') Map<String, dynamic>? users,

    /// The membership event type.
    @JsonKey(name: 'membership') MembershipEventTypes? membership,

    /// The display name of the user.
    @JsonKey(name: 'displayname') String? displayName,

    // For Images
    @JsonKey(name: 'url') String? url,
  }) = _MessageContent;

  /// Creates a [MessageContent] instance from a JSON map.
  factory MessageContent.fromJson(Map<String, dynamic> json) =>
      _$MessageContentFromJson(json);

  /// Creates an initial [

  factory MessageContent.initial() => MessageContent(
        msgType: UNKNOWN,
        body: UNKNOWN,
        topic: UNKNOWN,
        name: UNKNOWN,
        guestAccess: UNKNOWN,
        historyVisibility: UNKNOWN,
        joinRule: UNKNOWN,
        alias: UNKNOWN,
        creator: UNKNOWN,
        roomVersion: UNKNOWN,
        users: <String, dynamic>{},
        membership: MembershipEventTypes.unknown,
        displayName: UNKNOWN,
        url: UNKNOWN,
      );
}
