import 'dart:io';

import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/communities/core/utils.dart';

import '../../mocks.dart';

void main() {
  group('utils', () {
    test('should fetch room power levels', () async {
      final Map<String, dynamic> powerLevels =
          await fetchRoomPowerLevels('test-room', MockGraphQlClient());

      expect(powerLevels, isA<Map<String, dynamic>>());
      expect(powerLevels.containsKey('users'), true);

      expect(powerLevels['users'], isA<Map<String, dynamic>>());
    });

    test('should convert mime types', () async {
      expect(() => convertMimeTypes(File('example.png'), null),
          throwsA(isA<String>()));

      expect(convertMimeTypes(File('example.png'), 'image/png'),
          equals('image/png'));

      expect(convertMimeTypes(File('example.heic'), 'image/png'),
          equals('image/heic'));
    });

    test('should pick an image', () async {
      final File? file = await selectPhoto(picker: ImagePickerMock());

      expect(file, isNotNull);
      expect(file, isA<File>());
      expect(file?.path, isNotNull);
    });
  });
}
